Cone.Compiler (Cone v0.1.0)
View SourceThe main entry point for compiling Cone source code into Lamport IR and Tabular IR.
Summary
Functions
Compiles source code string into Tabular IR.
The main entry point for compiling Cone source code into Lamport IR and Tabular IR.
Compiles source code string into Tabular IR.