Cone.TabularIR.Pass behaviour (Cone v0.1.0)
View SourceBehavior for a compiler pass that operates on the Tabular IR (LCT).
Summary
Types
@type context() :: keyword()
@type table() :: [Cone.TabularIR.Row.t()]
Behavior for a compiler pass that operates on the Tabular IR (LCT).
@type context() :: keyword()
@type table() :: [Cone.TabularIR.Row.t()]